==> tuia-treasure-center-api-0.0.11_5-20180723.025008-1-sources.jar: cn/tuia/tuia/treasure/center/api/dto/ArticleThirdDto.java <==
package cn.tuia.tuia.treasure.center.api.dto;

/**
 * @Auther: wsz
 * @Date: 2018/7/20 17:23
 * @Description:
 */
public class ArticleThirdDto {
    private String title;
    /**
     * 文章摘要
     */
    private String articleAbstract;
    /**
     * 封面图片
     */
    private String headImgUrl;
    /**
     * 作者账号Id
     */
    private Long accountId;
    /**
     * 文章来源
     */
    private Integer articleSource;
    /**
     * 第三方平台id
     */
    private String thirdArticleId;
    /**
     * 文章内容
     */
    private String content;

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getArticleAbstract() {
        return articleAbstract;
    }

    public void setArticleAbstract(String articleAbstract) {
        this.articleAbstract = articleAbstract;
    }

    public String getHeadImgUrl() {
        return headImgUrl;
    }

    public void setHeadImgUrl(String headImgUrl) {
        this.headImgUrl = headImgUrl;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public Integer getArticleSource() {
        return articleSource;
    }

    public void setArticleSource(Integer articleSource) {
        this.articleSource = articleSource;
    }

    public String getThirdArticleId() {
        return thirdArticleId;
    }

    public void setThirdArticleId(String thirdArticleId) {
        this.thirdArticleId = thirdArticleId;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }
}

==> tuia-treasure-center-api-2.9.0.0-20191010.092735-1-sources.jar: cn/tuia/tuia/treasure/center/api/dto/ArticleThirdDto.java <==
package cn.tuia.tuia.treasure.center.api.dto;

import java.io.Serializable;

/**
 * @Auther: wsz
 * @Date: 2018/7/20 17:23
 * @Description:
 */
public class ArticleThirdDto implements Serializable{
    private static final long serialVersionUID = 6232217242761979213L;
    private String title;
    /**
     * 文章摘要
     */
    private String articleAbstract;
    /**
     * 封面图片
     */
    private String headImgUrl;
    /**
     * 作者账号Id
     */
    private Long accountId;
    /**
     * 文章来源
     */
    private Integer articleSource;
    /**
     * 第三方平台文章id
     */
    private String thirdArticleId;
    /**
     * 第三方平台作者id
     */
    private String thirdAccountId;
    /**
     * 文章内容
     */
    private String content;
    /**
     * 文章标签
     */
    private String tags;

    public String getThirdAccountId() {
        return thirdAccountId;
    }

    public void setThirdAccountId(String thirdAccountId) {
        this.thirdAccountId = thirdAccountId;
    }

    public String getTags() {
        return tags;
    }

    public void setTags(String tags) {
        this.tags = tags;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getArticleAbstract() {
        return articleAbstract;
    }

    public void setArticleAbstract(String articleAbstract) {
        this.articleAbstract = articleAbstract;
    }

    public String getHeadImgUrl() {
        return headImgUrl;
    }

    public void setHeadImgUrl(String headImgUrl) {
        this.headImgUrl = headImgUrl;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public Integer getArticleSource() {
        return articleSource;
    }

    public void setArticleSource(Integer articleSource) {
        this.articleSource = articleSource;
    }

    public String getThirdArticleId() {
        return thirdArticleId;
    }

    public void setThirdArticleId(String thirdArticleId) {
        this.thirdArticleId = thirdArticleId;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }
}
